==> kaizen-cli-0.1.43.tgz: package/src/components/Plugins/List/index.js <==
const Log = require('../../../lib/Log');
require('colors');

function builder(yargs) {
  
}

async function handler(argv) {
  Log.NormalLog('Available plugin list:');
  Log.NormalLog('bluzelle'.underline.yellow + ' - Bluzelle information');
  Log.NormalLog('nkn'.underline.yellow + ' - NKN information');
  Log.NormalLog('noia'.underline.yellow + ' - NOIA information');
  Log.NormalLog('icon'.underline.yellow + ' - ICON information');
  Log.NormalLog('orbit'.underline.yellow + ' - Orbit information');
  Log.NormalLog('arweave'.underline.yellow + ' - Arweave information');
  Log.NormalLog('band'.underline.yellow + ' - Band Protocol information');
  Log.NormalLog('fluence'.underline.yellow + ' - Fluence information');
  Log.NormalLog('sia'.underline.yellow + ' - Sia information');
  Log.NormalLog('near'.underline.yellow + ' - Near information');
  Log.NormalLog('tellor'.underline.yellow + ' - Tellor information');
  Log.NormalLog('skale'.underline.yellow + ' - Skale information');
  Log.NormalLog('ren'.underline.yellow + ' - Ren information');
  Log.NormalLog('nervos'.underline.yellow + ' - Nervos information');
  Log.NormalLog('kava'.underline.yellow + ' - Kava information');
  Log.NormalLog('zabo'.underline.yellow + ' - Zabo information');
  Log.NormalLog('loom'.underline.yellow + ' - Loom information');
  Log.NormalLog('witnet'.underline.yellow + ' - Witnet infromation');
  Log.NormalLog('ramp'.underline.yellow + ' - Ramp infromation');
  Log.NormalLog('0xcert'.underline.yellow + ' - 0xcert infromation');
  Log.NormalLog('keep'.underline.yellow + ' - Keep informatino');

  Log.NormalLog("\nTo install a plugin run " + "'kaizen plugins install <plugin-name-here>'".yellow)

  Log.NormalLog("\nIt will be automatically downloaded and added to your " + "'package.json'".yellow + " and " + "'kaizen.json'".yellow + " file\n");
}

module.exports = function (yargs) {
  const command = 'list';
  const commandDescription = 'Lists all available plugins';
  yargs.command(command, commandDescription, builder, handler);
}

==> kaizen-cli-0.1.44.tgz: package/src/components/Plugins/List/index.js <==
const Log = require('../../../lib/Log');
require('colors');

function builder(yargs) {
  
}

async function handler(argv) {
  Log.NormalLog('Available plugin list:');
  Log.NormalLog('bluzelle'.underline.yellow + ' - Bluzelle information');
  Log.NormalLog('nkn'.underline.yellow + ' - NKN information');
  Log.NormalLog('noia'.underline.yellow + ' - NOIA information');
  Log.NormalLog('icon'.underline.yellow + ' - ICON information');
  Log.NormalLog('orbit'.underline.yellow + ' - Orbit information');
  Log.NormalLog('arweave'.underline.yellow + ' - Arweave information');
  Log.NormalLog('band'.underline.yellow + ' - Band Protocol information');
  Log.NormalLog('fluence'.underline.yellow + ' - Fluence information');
  Log.NormalLog('sia'.underline.yellow + ' - Sia information');
  Log.NormalLog('near'.underline.yellow + ' - Near information');
  Log.NormalLog('tellor'.underline.yellow + ' - Tellor information');
  Log.NormalLog('skale'.underline.yellow + ' - Skale information');
  Log.NormalLog('ren'.underline.yellow + ' - Ren information');
  Log.NormalLog('nervos'.underline.yellow + ' - Nervos information');
  Log.NormalLog('kava'.underline.yellow + ' - Kava information');
  Log.NormalLog('zabo'.underline.yellow + ' - Zabo information');
  Log.NormalLog('loom'.underline.yellow + ' - Loom information');
  Log.NormalLog('witnet'.underline.yellow + ' - Witnet infromation');
  Log.NormalLog('ramp'.underline.yellow + ' - Ramp infromation');
  Log.NormalLog('0xcert'.underline.yellow + ' - 0xcert infromation');
  Log.NormalLog('keep'.underline.yellow + ' - Keep information');
  Log.NormalLog('torus'.underline.yellow + ' -Torus infomration');

  Log.NormalLog("\nTo install a plugin run " + "'kaizen plugins install <plugin-name-here>'".yellow)

  Log.NormalLog("\nIt will be automatically downloaded and added to your " + "'package.json'".yellow + " and " + "'kaizen.json'".yellow + " file\n");
}

module.exports = function (yargs) {
  const command = 'list';
  const commandDescription = 'Lists all available plugins';
  yargs.command(command, commandDescription, builder, handler);
}
